#
# spec file for package werf
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           werf
Version:        2.35.0
Release:        1.1
Summary:        CLI for the Werf CI/CD system
License:        Apache-2.0
URL:            https://github.com/werf/werf
Source:         werf-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.22.7
BuildRequires:  zsh
#
BuildRequires:  device-mapper-devel
BuildRequires:  libbtrfs-devel
BuildRequires:  libcontainers-common
BuildRequires:  libgpgme-devel

%description
werf is a CNCF Sandbox CLI tool to implement full-cycle CI/CD to Kubernetes easily. werf integrates into your CI system and leverages familiar and reliable technologies, such as Git, Dockerfile, Helm, and Buildah.

What makes werf special:
* Complete application lifecycle management: build and publish container images, test, deploy an application to Kubernetes, distribute release artifacts and clean up the container registry.
* Ease of use: use Dockerfiles and Helm chart for configuration and let werf handle all the rest.
* Advanced features: automatic build caching and content-based tagging, enhanced resource tracking and extra capabilities in Helm, a unique container registry cleanup approach, and more.
* Gluing common technologies: Git, Buildah, Helm, Kubernetes, and your CI system of choice.
* Production-ready: werf has been used in production since 2017; thousands of projects rely on it to build & deploy various apps.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="-X github.com/werf/werf/v2/pkg/werf.Version=%{version}" \
   -tags="dfrunsecurity dfrunnetwork dfrunmount dfssh containers_image_openpgp osusergo exclude_graphdriver_devicemapper netgo no_devmapper static_build" \
   -o bin/werf ./cmd/werf

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{name}

%changelog
* Fri Apr  4 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 2.35.0:
  * Features
  - build: add clearUser and clearWorkingDir options to imageSpec
    config (#6759) (36f3d6a)
  - build: add pull/push retries when authentication is required
    (short-term token case) #6750 (26ccd15)
  - cleanup: add disable cleanup feature (#6737) (78f4e20)
  * Bug Fixes
  - build, docker: fix failed to find driver "docker-container"
    (#6760) (63dcbfb)
  - host-cleanup: don't prune backend build cache (7963926)
  - host-cleanup: don't prune containers #6762 (fa242d8)
  - host-cleanup: don't prune dangling werf images for some time
    (#6767) (fd9b2ca)
  - host-cleanup: don't prune dangling werf images for some time
    (Docker) (#6752) (c0d3413)
  - host-cleanup: ensure no parallel processes of auto host
    cleanup (#6736) (9b43ad0)
  - host-cleanup: purge Stapel assembling container (785fa77)
* Wed Mar 26 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.34.1:
  * Bug Fixes
  - build, buildah, staged: fix panic in run instruction (#6733)
    (579de54)
  - build, imageSpec: keep essential werf labels (469a065)
  - cleanup: handle fromImage properly by kubernetes and
    builtWithinLastNHours policies (7cffc4b)
* Tue Mar 25 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.34.0:
  * Features
  - build, imageSpec: support template werf variables (%%image%%,
    %%project%%) for labels (#6724) (bb2dfc4)
  * Bug Fixes
  - host-cleanup: fix locking doesn't work as expected #6725
    (bbd7a55)
* Tue Mar 25 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.33.0:
  * Features
  - deploy: save service annotations inside Helm release
    (24b47ad)
  * Bug Fixes
  - cli: add error handling in case of non-existent command
    entered (d5c548c)
  - host-cleanup: don't stop removing werf containers on paused
    or running ones (3373d0c)
* Wed Mar 19 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.32.2:
  * chore: release 2.32.2
  * fix(build, staged): fix cache mounts (#6714)
  * chore: fix failed lint
  * refactor(cleanup): do git history based cleanup concurrently
    (#6708)
  * fix(run): "docker run" should control output direcly
  * refactor(run): SyncContextCliWithLogger() is unused
  * refactor(run): DockerCliOption is deprecated
  * docs(telemetry): actualize
  * docs(cr-login): update example (#6711)
  * refactor(cleanup): add detailed error for invalid regex in
    config
  * docs(build): fix header (#6709)
  * chore(release): 2 alpha
* Mon Mar 17 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.32.1:
  * chore: release 2.32.1 (#6707)
  * chore: release 2.32.1
  * Revert "refactor(cleanup): perform git history based cleanup
    concurrently (#6…" (#6706)
  * wip
  * refactor(deploy): update Nelm dependency
  * docs(cleanup): update in werf.yaml reference
  * chore(release): 1.2 stabe, 2 alpha
* Fri Mar 14 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.32.0:
  * chore: release 2.32.0 (#6693)
  * refactor(cleanup): perform git history based cleanup
    concurrently (#6702)
  * feat(cleanup): keep dependencies (#6704)
  * feat(host-cleanup): clean up dangling and regular images,
    unused volumes, stopped containers, build cache (#6687)
  * feat: support `WERF_PRINT_STACK_TRACES=1` env var for period
    stack traces
  * fix(cleanup): speed-up image metadata inition
  * refactor(buildah): remove code duplication
  * fix(build, imageSpec): resolve env issues, labels warning, and
    add --skip-image-spec-stage flag (#6651)
  * refactor(deploy): move some secrets code to Nelm
  * refactor(deploy): migrate `werf helm secret` commands to Nelm
    actions
  * refactor(giterminism, buildah): replace third party error
    packages with std lib errors pkg
  * chore(dev): run lint task in container and update
    CONTRIBUTING.md (#6686)
  * refactor(deploy): unfreeze `werf helm secret` commands code
  * refactor(deploy): freeze more of `werf helm` code
  * fix(host-cleanup): test werf/exec process detach
  * fix(host-cleanup): auto host cleanup doesn't work on linux
  * feat(deploy): add syntax highlight to `render` and `bundle
    render`
  * chore(channels): bump early-access, stable
  * chore(channels): hotfix
* Thu Mar  6 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.31.1:
  * chore: release 2.31.1
  * fix(deploy): `bundle copy` panics
  * chore: update Nelm module
  * refactor(cli): revert quoting for non-string flag value
  * chore(release): 2 alpha,beta
* Wed Mar  5 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.31.0:
  * chore: release 2.31.0
  * chore(release): 2 ea,stable
  * chore(dev): add task for gofumpt installation (#6679)
  * chore(dev): add task for gci formatter installation (#6677)
    (#6677)
  * feat(export): support multiple values within --add-label flag
  * feat(converge): support multiple values within
  - -add-annotation/--add-label flag
  * refactor(cli): quote flag value
  * fix(build, docker, dockerfile): fix panic expected stage
    "dockerfile" content digest label to be set!
  * refactor(build): remove unused code
  * chore(release): 2 alpha,beta
* Wed Mar  5 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.30.1:
  * chore: release 2.30.1 (#6674)
  * chore(release): release 2.30.1
  * Revert "refactor(cleanup): add parallel execution for git
    history-based clean…" (#6673)
  * chore: fix lint error
  * refactor(deploy): update Nelm dependency
  * chore(release): 1.2, 2
* Fri Feb 28 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.30.0:
  * chore: release 2.30.0 (#6669)
  * chore(release, werf-in-image): rebuild all images
  * refactor(cleanup): add parallel execution for git history-based
    cleanup (#6657)
  * feat(build): add `build.cacheVersion` and
    `<image>.cacheVersion` directives (#6643)
  * docs(cleanup): fix typo
  * feat(cleanup): make cleanup defaults more aggressive
  * chore(channels): bump alpha
* Wed Feb 26 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.29.0:
  * chore: release 2.29.0
  * feat(deploy): print templated manifests when they are invalid
    and `--debug` enabled
  * refactor(deploy): update nelm module
  * docs(deploy): add `werf.io/sensitive` annotation
  * feat(deploy): add `werf.io/sensitive` annotation
  * fix(deploy): External Secret CR falsely readying if has no
    status early on
  * chore(ci): pin binfmt:qemu version to prevent segmentation
    fault
  * chore(release, werf-in-image): disable fail-fast for image
    publication
  * chore(release): 2 alpha
* Mon Feb 24 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.28.0:
  * chore: release 2.28.0
  * chore(deps): update nelm/3p-helm
  * docs(cleanup): small improvement (#6654)
  * feat(host-cleanup): support Buildah backend (#6575)
  * feat(config): add .Files.Exists and .Files.IsDir Go template
    functions
  * refactor(giterminism): add file system layer to make it
    mockable
  * refactor(giterminism): use errors.As() instead of switch type
    for custom error type
  * refactor(giterminism): improve code readability through
    simplification of logboek debugging
  * chore(release, cleanup): add cleanup policy (#6650)
  * docs(cleanup): improve clarity of the article
  * chore(release): 2 alpha,beta,ea,rock-solid
* Wed Feb 19 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.27.1:
  * chore: release 2.27.1
  * refactor(build): remove unused code
  * fix(build, buildah, dockerfile, staged): fix <bin>: no found
    (invalid PATH)
  * test(dev): add mockgen to mock generation
  * chore(build): remove warning in docker mode
* Wed Feb 12 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.27.0:
  * chore(channels): bump channels
  * refactor(build): improve http retry after header handling logic
    (#6620)
  * chore: release 2.27.0
  * feat(deploy): support `werf_secret_file` Helm function in
    bundle apply/render
  * fix(deploy): `inconsistent data, unpad failed` error in bundle
    apply/render
  * test(e2e): simplify simple bundle publish/apply test
  * test(e2e): add complex bundle publish/apply test
  * chore(release): 2 alpha
* Mon Feb 10 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.26.6:
  * chore: release 2.26.6
  * fix(build, image-spec): remove werf SSH_AUTH_SOCK env that
    persist after build
  * chore(release): 2 alpha
* Mon Feb 10 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.26.5:
  * chore: release 2.26.5
  * fix(build, image-spec): remove werf envs that persist after
    build
  * chore(release): 2 alpha
* Mon Feb 10 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.26.4:
  * chore: release 2.26.4
  * fix(build): account for imagesSpec.clearCmd/clearEntrypoint
    when generating image tag
  * fix(build): ensure imageSpec preserves CMD and ENTRYPOINT
    behavior for compatibility
  * chore(channels): bump alpha
* Sat Feb  8 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.26.3:
  * test(e2e): force `kubectl delete ns` at the end of complex
    converge test to be safe
  * test(e2e): add simple `bundle publish/apply` apply test
  * chore: release 2.26.3
  * fix(cleanup): panic in `werf cleanup`
  * fix(deploy): panics in bundle apply and bundle render
  * fix(deploy): bundle publish might publish empty bundle
  * fix(deploy): panic in many commands when
    `--synchronization=kubernetes://...`
  * Update trdl_channels.yaml
* Fri Feb  7 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.26.2:
  * chore: release 2.26.2 (#6621)
  * fix(build): invalidate imageSpec cache
  * chore(release): 2 alpha
* Fri Feb  7 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.26.1:
  * chore: release 2.26.1 (#6619)
  * fix(build): ensure imageSpec.config.env variables are expanded
    (#6618)
  * test(e2e): in complex converge test never cleanup CRDs because
    it breaks parallel runs
  * chore(release): 2 alpha
* Fri Feb  7 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.26.0:
  * chore: release 2.26.0
  * feat(build): apply global imageSpec only for final images
  * refactor(deploy): get rid of ChartExtender and all its
    implementations
  * chore(release): 2 alpha
* Fri Feb  7 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.25.1:
  * chore: release 2.25.1
  * fix(build): panic: assignment to entry in nil map
  * chore(docs): add user option to werf cr login (#6608)
  * chore(release): 2 alpha
* Fri Feb  7 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.25.0:
  * chore: release 2.25.0 (#6595)
  * fix(build): fix secret config validation not working (#6598)
  * fix(build): fix no such image error
  * fix(build): fix incorrect base image when user removes werf
    labels
  * refactor(build): dedup code
  * fix(build): fix incorrect base image when imageSpec used
  * refactor(deploy): move service values handling out of legacy
    pre-deploy Nelm hooks
  * chore(release): 2 alpha
  * fix(deploy): subcharts rendered incorrectly
  * refactor(deploy): get rid of subchart ChartExtender
    implementation
  * refactor(deploy): update Nelm module
  * refactor(deploy): clean up pre-deploy hook functions of Nelm
    actions
  * refactor(deploy): annotations and labels management moved out
    of ChartExtender implementations
  * fix(build): fix ssh auth sock validation (#6599)
  * refactor(host-cleanup): support container backend (#6573)
  * docs: regen cli reference
  * refactor(deploy): minor changes
  * feat(deploy): add --skip-dependencies-repo-refresh,
  - -show-only, --disable-default-values to `bundle render`
  * fix(deploy): subchart secret values not disabled via
  - -disable-default-secret-values in `bundle apply`
  * chore(release): 2 alpha
  * refactor(deploy): migrate `bundle render` to Nelm actions
* Fri Feb  7 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.24.0:
  * chore: release 2.24.0
  * feat(build): add mutate image spec config feature (#6578)
  * docs: regen cli
  * feat(deploy): add --disable-default-values and
  - -disable-default-secret-values flags to `bundle apply`
  * refactor(deploy): migrate `bundle apply` to Nelm actions
  * feat(deploy): vendor chart dependencies in bundle during
    `bundle publish`
  * chore(channels): bump channels
* Thu Jan 30 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.23.1:
  * chore: release 2.23.1
  * fix(deploy): `bundle publish` panics if remote dependencies
    cache not up to date
  * refactor(deploy): move bundles code out of chart_extender pkg
  * fix(deploy): deploy.helmChartConfig.appVersion in werf.yaml
    ignored for bundles
  * chore(release): 2 alpha,ea,stable,rock-solid
* Tue Jan 28 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.23.0:
  * chore: release 2.23.0 (#6562)
  * refactor(deploy): move some deploy-related code to Nelm/Helm
  * test(build): fix WERF_FORCE_STAGED_DOCKERFILE support
  * chore: fix lint
  * refactor(test): simplify cleanup suite
  * test(cleanup): test kubernetes based policy with imports
  * fix(cleanup): handle --keep-stages-built-within-last-n-hours=0
    properly
  * refactor(build): fix log message
  * refactor(build): remove unused import metadata field
  * feat(cleanup): keep import source images
  * refactor(build, stapel, imports): use source stage id instead
    of image ID
  * docs: update the installation link
  * docs(deploy): add separate "Authentication" section (#6569)
  * fix(docs): replace latest with main
  * feat(build): add global staged directive
  * fix(build): try to fix response body closed error
  * refactor(build): update backoff
  * chore(release, builder): update go@1.22.7 up to go@1.23.5
    (#6568)
  * feat(release): add channel version images (#6565)
  * chore(ci, release): update workflows (#6560)
  * fix(deploy): plan should not require --repo
  * chore(channels): bump channels
  * docs(deploy): small improvements
  * feat(build): fix typo
  * feat(build): retry 429 err for docker cli push/pull
  * feat(build): retry 429 err for "werf cr login <registry>"
  * chore(channels): bump alpha
* Wed Jan 22 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.22.0:
  * chore: release 2.22.0
  * docs: regen cli reference
  * feat(deploy): add --skip-tls-verify-kube, --kube-api-server,
  - -kube-ca-path, --kube-tls-server, --kube-token,
  - -skip-tls-verify-helm-dependencies options to bundles
  * docs: regen cli reference
  * feat(deploy): add --kube-qps-limit and --kube-burst-limit
    flags, increase default QPS/Burst
  * feat(kube-run): support %%container_image%% in overrides (#6553)
  * chore(ci): pin ubuntu version
* Tue Jan 21 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.21.0:
  * chore: release 2.21.0
  * feat(deploy): add --skip-tls-verify-kube, --kube-api-server,
  - -kube-ca-path, --kube-tls-server, --kube-token,
  - -skip-tls-verify-helm-dependencies options (retrigger CI)
  * chore(channels): bump alpha
  * docs: regen cli reference
  * feat(deploy): add --skip-tls-verify-kube, --kube-api-server,
  - -kube-ca-path, --kube-tls-server, --kube-token,
  - -skip-tls-verify-helm-dependencies options
* Mon Jan 20 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.20.0:
  * docs: regen cli reference
  * chore: release 2.20.0
  * feat(deploy): add `--kube-context`, `--kube-config`,
    `--kube-config-base64` flags to `bundle apply`
  * feat(build): add field final to build report
  * docs(contributing): small improvement
  * chore(release): 2 alpha,beta
* Thu Jan 16 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.19.0:
  * chore: release 2.19.0
  * fix(deploy): LastError empty in logs on failures for some
    resources
  * fix(cr-login): fix UserAgent
  * feat(deploy): ExternalSecret CR tracking works again
  * fix(deploy): `hidden sensitive output` message in plan for
    Secrets even if no sensitive changes
  * chore(taskfile, build): optional version for dev binary
  * chore(taskfile, build): refactor go and cgo variables
  * test(e2e): remove unused Chart.lock from complex converge test
  * refactor(deploy): move dependency management from werf to
    nelm/helm
  * chore(release): 1.2 rock-solid, 2 alpha,beta,ea,stable
* Wed Jan 15 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.18.0:
  * chore: release 2.18.0 (#6533)
  * feat(build): force use the only one sync server (#6512)
  * fix(helm): pass --debug option to helm
  * chore(docs): fix redirects for v1.1 (#6500)
  * fix(deploy): compiling error — unused import
  * feat(deploy): kube-run won't require list permissions for pods
    and secrets
  * fix(deploy): kube-run should not require any namespace
    permissions
  * docs(images): small improvements
  * chore(ci): fix lint (#6529)
  * docs: small improvements (#6527)
  * docs: add build backends and werf images articles (#6491)
  * chore(ci): update release and publish actions (#6511)
  * chore(docs): increase the priority of usage pages (#6523)
  * chore(ci): add milliseconds to artifact name (#6525)
  * test(e2e): rewrite and expand complex converge test
  * chore(ci): disable quai tests
  * test(converge): fix flapping complex converge tests
  * fix(build, report): add non-final images
  * fix(deploy): panics with subcharts
  * refactor(deploy): move secrets handling to 3p-helm and
    common-go
  * chore: test ci
  * refactor(deploy, build): move util and secret packages to
    github.com/werf/common-go
  * refactor(deploy): move part of GiterminismManager interface to
    3p-helm
  * fix(test): add giterminism for plain secret value
  * chore(release): 2 alpha
* Thu Dec 19 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.17.0:
  * chore: release 2.17.0 (#6504)
  * feat(build, secrets): include plain secret values in
    giterminism scope (#6495)
  * chore(release): 1.2 stable, 2 beta,ea,rock-solid
  * chore(ci): rename project name (#6502)
  * refactor(deploy): freeze helm/nelm/kubedog and werf deploy code
    for `werf helm` commands
  * chore(ci): update notification (#6499)
  * docs(build): remove outdated note about staged dockerfile
    (#6501)
  * chore(ci): сonsider images in test clusters during deletion
    (#6492)
* Tue Dec 17 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.16.3:
  * fix
  * fix(build) trim ssh flag for legacy docker build
  * chore(docs): fix ref link
  * chore: release 2.16.3
  * chore(channels): bump alpha
  * fix(deploy): autorollback in converge was always disabled
  * refactor(build): remove ssh sock from conveyor and add default
    agent  (#6489)
  * chore(ci): fix depricated warnings (#6485)
  * refactor(test): use go task to build dev binary (#6483)
  * fix(build): fix data races (#6477)
  * chore(ci): fix workflow_dispatch notification
  * chore(release): alpha,beta,ea,stable
* Tue Dec 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.16.2:
  * chore: release 2.16.2 (#6479)
  * fix(deploy): fix segfault in get-release (#6486)
  * chore(release): 2 stable
  * docs(deploy): overriding appVersion during deploy
  * chore(site): fix tls key (#6482)
  * chore(docs): update ci cd doc
  * fix(deploy): deploy graph cycle if same external dependency on
    multiple resources
  * fix(deploy): initial resource status should be "unknown"
    instead of "created"
  * chore(release): 1.2 alpha,beta,ea,stable(-) 2 alpha,beta
* Thu Dec  5 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.16.1:
  * chore: release 2.16.1 (#6473)
  * fix(deploy): ignore error "Additional property werf is not
    allowed"
  * fix(deploy): no resources deleted in uninstall if pre-delete
    hook present
  * fix(export): resolve issue with exporting specific images
    (#6471)
  * chore(channels): bump alpha
* Wed Dec  4 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.16.0:
  * chore: release 2.16.0
  * fix(deploy): hooks might run twice
  * feat(werf): add helmChartConfig property to werf.yaml
  * chore(ci): remove deploy test docs
* Wed Dec  4 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.15.3:
  * chore: release 2.15.3
  * chore(release): 2 alpha,beta (#6465)
  * chore(ci): remove inputs in reusable workflow (#6464)
  * chore(channels): bump alpha
* Wed Dec  4 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.15.2:
  * chore: release 2.15.2
  * fix(deploy): global encryption key (~/.werf/global_secret_key)
    ignored
  * fix(ci): try to fix error (#6461)
  * chore(channels): bump alpha 2
* Wed Dec  4 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.15.1:
  * chore: release 2.15.1
  * fix(deploy): "unable to release lock" errors in werf dismiss
  * chore(release): 1.2 alpha,stable 2 alpha,beta
* Wed Dec  4 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.15.0:
  * chore: release 2.15.0
  * fix(build, buildah, stapel): prevent build failure on invalid
    dest link (#6453)
  * docs: small fixes and improvements
  * feat(build, buildah, dockerfile, staged): add secrets support
    (#6454)
  * fix(cleanup): resolve potential deadlock issue
  * refactor(cleanup): remove duplicate code
  * refactor: always use live output for parallel tasks
  * fix(cleanup): handle Too Many Requests (429) (#6455)
  * chore(ci): update notification (#6441)
  * docs(stapel): add secrets usage to instructions (#6448)
  * fix(build, secrets) resolve path with tilde (#6450)
  * refactor(werf-in-image): optimize build (#6451)
  * feat(build, docker, buildah, stapel): add secrets support
    (#6446)
  * docs(build, secrets): update example
  * chore(release): 2 alpha
  * chore(release): 1.2 ea, 2 rock-solid
* Wed Nov 27 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.14.0:
  * chore: release 2.14.0 Signed-off-by: Aleksei Igrychev
    <aleksei.igrychev@palark.com>
  * docs(build, dockerfile, giterminism): add secrets description
    (#6443)
  * refactor(util): fix ExpandPath does not support "~"
  * refactor(util): enhance path utility functions
  * fix(cleanup): fix cleanup for Buildah images by switching to
    tag-based logic
  * refactor(cleanup): make it juicy
  * feat(giterminism): add build secrets (#6436)
  * chore(test): do not user artifacts
  * feat(build, docker, buildah, dockerfile): add secrets support
    (#6429)
  * fix: unsorted Set.ToSlice usage in parallel task execution
  * chore(release): add registry cleanup workflow (#6428)
  * feat(release): publish werf images for linux/arm64 platform
    (#6427)
  * refactor(cleanup): do not override the keep reason
  * refactor(cleanup): introduce StageDescSet and unify array
    handling
  * fix(cleanup): keep relatives for
    keepImagesBuiltWithinLastNHours policy
  * refactor(build): deduplicate selectSuitableStageDesc
  * refactor: introduce StageDescSet and unify array handling
  * refactor: standardize usage of StageDesc naming
  * refactor(cli): add common components manager to deduplicate
    code (#6414)
  * chore(ci): fix the workflow is not valid
  * chore(release): 1.2 beta,rock-solid 2 all
* Wed Nov 20 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.13.1:
  * chore: release 2.13.1 (#6423)
  * fix(bundle): allow
    application/vnd.cncf.helm.chart.content.v1.tar+gzip media type
    (#6424)
  * chore(deps): update docs/Gemfile & docs/Gemfile.lock to reduce
    vulnerabilities (#6426)
  * fix(build, buildah): support custom docker config path (#6421)
  * refactor(test): use "Expect" instead of "Ω"
  * chore(site): change basic auth to dex (#6416)
  * chore(release): 1.2 alpha
  * docs(deploy): fix excess repo option in example
  * docs(build): note about build backends in overview
  * docs(build): fix example with multi-stage build
  * docs(kubectl): generate docs for log flags
  * refactor(ci): replace action converge with werf command
  * chore(release): 1.2 stable/rock-solid 2 all
  * fix(kubectl): add klog arbitrary flags
* Thu Nov 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.13.0:
  * chore: release 2.13.0 (#6404)
  * Revert "chore(ci): replace action converge with werf command
    (#6410)" (#6417)
  * chore(ci): replace action converge with werf command (#6410)
  * refacor(test): add repo option to compose test (#6411)
  * refactor(test): set predefined host port for registry container
    (#6408)
  * refactor(docs): actualise cr cli param help message (#6405)
  * test(e2e, export): test basic and multiplatform scenarios
    (#6387)
  * test: fix registry:2 image not found error (#6407)
  * feat(build, docker): use buildkit by default (#6401)
* Tue Nov 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.12.1:
  * chore: release 2.12.1 (#6400)
  * chore(release): 2 alpha
  * fix(export): fix worker log output (#6399)
  * refactor(test) refactor compose test (#6397)
  * chore(release): 1.2 ea,stable 2 all
* Tue Nov 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.12.0:
  * chore: release 2.12.0 (#6396)
  * feat(export): export images concurrently(#6395)
  * refactor(cli): refactor storage manager
  * refactor(cli): refactor storage manager
  * refactor(dev): werf cli deduplicate storage manager
  * chore(release, werf-in-image): fix unexpected EOF while looking
    for matching `"'
  * chore(release, werf-in-image): fix invalid base image
  * chore(release): fix build arguments (e.g., TARGETARCH ) not
    available
  * Revert "chore(ci): add ghcr cleanup (#6383)"
  * revert: release werf images for linux/arm64 platform
  * chore(release): 2 alpha
  * chore(release): 2 alpha
* Sat Nov  2 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.11.0:
  * chore: release 2.11.0
  * test(e2e, compose): add compose e2e test (#6385)
  * chore(werf-in-image): optimize build and export
  * chore(ci): add ghcr cleanup (#6383)
  * Fix color in configurator table (#6386)
  * docs(contributing): update supported scopes (#6384)
  * chore(deps): update go-git from v5.10.1 to v5.12.0 (#6379)
  * feat(release): add crane to werf images (#6377)
  * fix(release): fix /home/build/.werf: permission denied when
    volume is used with werf images (#6382)
  * Revert "chore(release): 1.2 ea,stable 2 ea,stable,rock-solid"
  * chore(release): 1.2 ea,stable 2 ea,stable,rock-solid
  * fix(deploy): ensure werf commands run consistently with service
    values
  * refactor(deploy, get-autogenerated-values): rename
    commonCmdData with getAutogeneratedValuedCmdData
  * feat(release): add tzdata to werf images (#6376)
  * fix(deploy): ensure werf commands run consistently without
    images or with stubs
  * fix(build,docker): remove quiet mode when using buildkit
  * chore(werf-in-image): fix required version getting
  * chore(ci): add friendly closure messages to auto-closed issues
  * chore(ci): fix issues:delayed-auto-close
  * chore(ci): enable issues:new-add-triage-label workflow
  * chore(ci): close issues with no user response
  * feat(release): distribute werf images for linux/arm64 plarform
  * fix(export, multiplatform): fix unexpected condition: stage
    image without labels
  * chore(export, multiplatform): update error message
  * fix(export, multiplatform): fix no child with platform
    linux/amd64 in index
  * chore(export): fix incorrect image color in log
  * docs(bundles): use custom image tags
  * fix(cleanup, ecr): fix aws sso not supported
  * chore(issue): add triage label to new issues
  * chore(release): 1.2 beta,ea 2 beta,ea,stable,rock-solid
  * chore(release): 1.2 alpha, 2 alpha
  * chore(release): 1.2 beta, 2 beta,ea,stable
* Thu Oct 17 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.10.10:
  * chore: release 2.10.10
  * fix(build, docker, dockerfile): remove ONBUILD support in base
    images to reduce overhead
  * fix: revert go-git to v5.10.1 due to broken backward
    compatibility
  * fix(build, stapel, docker): /.werf/stapel/embedded/bin/bash:
    warning: setlocale: LC_ALL: cannot change locale
  * fix(locker): replace panic with error and add details for lost
    lease case
* Wed Oct  2 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.10.9:
  * chore: release 2.10.9
  * chore(release): 2 alpha
  * chore(build): up builder image
  * chore(release): 1.2 alpha, 2 alpha,beta,ea
* Wed Oct  2 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.10.8:
  * chore: release 2.10.8
  * chore(build): up golang from 1.21.1 to 1.22.7
  * fix(build): allow usage of non-final images for specific
    commands
  * refactor(build): improve image handling logic
  * docs(build): fix header level
  * chore(release): 1.2 alpha,beta
* Fri Sep 27 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.10.7:
  * chore: release 2.10.7
  * fix: disable rendering of subchart notes by default
  * fix(compose): support image names with dot
  * docs(usage, cr-cleanup): update gitlab token section
  * chore(release): 1.2 rock-solid, 2 alpha
* Sat Sep 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.10.6:
  * chore: release 2.10.6
  * refactor(ci-env, gitlab): update annotation with job url
  * fix(ci-env, gitlab): fix annotation with pipeline url
  * chore(release): 1.2 stable, 2 rock-solid
  * docs(cli): update the config option description
  * refactor(synchronization, lock_manager): move and refactor code
  * refactor(synchronization, server): move and remove unused code
  * refactor(storage): remove unused code
  * chore(release): 1.2 alpha,beta,ea,rock-solid 2 all
* Tue Sep 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.10.5:
  * chore: release 2.10.5
  * fix(compose): correctly handle multiple compose files with
  - f/--file option
  * chore(release): 2 alpha,beta,ea
* Tue Sep 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.10.4:
  * chore: release 2.10.4
  * fix(build/stages): Add RWMutex to ImagesTree
  * chore(release): 1.2 beta,stable 2 beta,ea,stable
  * chore(channels): bump alpha 1.2, 2
* Fri Aug 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.10.3:
  * chore: release 2.10.3
  * fix(deploy): invalid labels/annotations silently remove all
    user labels/annotations for the resource
  * fix(build, buildah, stapel): prevent sensitive data exposure by
    not printing user commands
  * chore(release): 1.2 alpha,beta,ea,stable 2
    alpha,beta,ea,rock-solid
* Tue Aug 13 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.10.2:
  * chore: release 2.10.2
  * fix(compose): detect werf environment variables when extends
    functionality used
  * chore(ci): enable docs unit test
  * chore(ci): remove senseless profiling for e2e/integrations
    tests
  * test: update coverage profiling for integration tests
  * chore(ci): enable coverage for all daily tests
  * test(e2e, build, dockerfile): fix fixtures
  * test(e2e, build, dockerfile): test only
    WERF_STAGED_DOCKERFILE_VERSION=v2
  * chore(ci): uncomment complex e2e tests
  * fix(build, buildah, dockerfile, staged): fix panic when another
    image is used as a base image (through dependencies)
  * chore(channels): bump alpha
* Wed Aug  7 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.10.1:
  * chore(format): reformat imports
  * chore: release 2.10.1
  * fix(deploy): occasional panics on logging
  * fix(deploy): plan build error not showed and graph not saved
  * chore(deps): switch to renamed github.com/werf/3p-helm module
  * chore(release): 1.2 alpha, 2 alpha
  * chore(release): 1.2 beta,stable,rock-solid 2 beta,stable
* Wed Aug  7 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.10.0:
  * chore: release 2.10.0
  * docs(cleanup): remove imagesPerReference.operator as it causes
    confusion and offers no practical value
  * feat(cleanup): change default from unlimited to one image per
    reference
  * refactor(cleanup): refactor handling config defaults
  * feat(render): add --stub-tags option to explicitly ignore real
    tags
  * chore(release): 1.2 alpha, 2 alpha
* Thu Aug  1 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.9.3:
  * chore: release 2.9.3
  * fix(build, buildah, dockerfile, staged): 'ADD / /app' not
    working
  * chore(release): 1.2 alpha, 2 alpha
* Thu Aug  1 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.9.2:
  * chore: release 2.9.2
  * fix(build, buildah, dockerfile, staged): fix handling of CMD
    and ENTRYPOINT in exec format
  * fix(build, buildah, dockerfile, staged): ensure setting
    ENTRYPOINT correctly resets base image CMD
  * test(e2e, build, dockerfile): test CMD and ENTRYPOINT handling
  * chore(release): 1.2 ea,stable,rock-solid, 2 ea
  * chore(channels): bump alpha, beta
* Sat Jul 27 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.9.1:
  * chore: release 2.9.1
  * fix(deploy): panic on --synchronization=kubernetes://...
  * chore(release): rollback 2 ea,stable
  * chore(channels): bump 1.2, 2
  * chore(release): 1.2 alpha, 2 alpha
* Mon Jul 22 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.9.0:
  * chore: release 2.9.0
  * fix(compose): require arbitrary values for service values to
    run the down command
  * feat(compose): auto-extract used images from Docker Compose
    file if not specified
  * refactor(compose): add command to error
  * refactor(compose): use imagesProcess structure
  * fix(host-cleanup): remove invalid entries from git cache
* Wed Jul 17 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.8.0:
  * chore(channels): bump 1.2, 2
  * chore(ci): disable Slack notifications temporarily /2
  * chore(ci): disable Slack notifications temporarily
  * chore: release 2.8.0
  * fix(deploy): --kube-config option must have highest priority
  * refactor(build, buildah): fix image ID format
  * refactor(build): always keep container parentID in labels
  * fix(build, stapel): fix panic when unsupported scratch base
    image used
  * docs(build, images): fix example
  * docs(build, stapel): remove usages of nameless images
  * docs(development-ansible): removed due to the deprecation of
    this functionality
  * refactor: add optional new line in log
  * refactor: remove unnecessary empty line in global warning
    message
  * feat(docker-registry): use werf user agent for requests to
    container registry API
  * refactor(docker-registry): add common remote options to the
    tags request
  * refactor(docker-registry): refactor common remote options usage
  * chore(release): 1.2 alpha, 2 alpha
* Wed Jul 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.7.1:
  * chore: release 2.7.1
  * fix(ci-env): unable to copy /home/<user>/.docker/mutagen
  * fix: suppress warnings for some commands
  * docs(build): add cross-compilation section
  * chore(release): 1.2 alpha, 2 alpha
  * chore(release): 1.2 beta,rock-solid 2 beta,ea,stable,rock-solid
* Wed Jul 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.7.0:
  * chore: release 2.7.0
  * docs(build): move multi-platform and cross-platform building
    section
  * refactor: fix typo
  * refactor: update global warnings interface
  * refactor: refactor synchronization server GlobalWarningLn
  * refactor(config): update deprecation warning for artifact,
    fromArtifact and import.artifact
  * refactor(config): update deprecation warning for nameless image
  * refactor(config): add ansible deprecation warning
  * refactor: update global warnings format
  * docs: remove artifacts completely
  * feat(build, stapel): add disableGitAfterPatch directive
  * feat(build): add ability to regulate the final property of an
    image
  * refactor: unify treatment of stapel, dockerfile, and artifact
    images
  * docs(reference, config): actualize
  * refactor: update v1.3 to v3 in deprecation messages
  * refactor(build, buildah): update error message
  * fix(build): fix invalid image digest when cache repo used
  * test(build, stapel): remove outdated test
  * test: fix broken tests
  * chore(channels): bump alpha
* Wed Jul  3 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.6.7:
  * chore: release 2.6.7
  * fix(deploy): dependency between ClusterRoleBinding in
    non-release namespace and ClusterRole not detected
  * chore(release): 1.2 alpha, 2 alpha
* Wed Jul  3 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.6.6:
  * chore: release 2.6.6
  * fix(build): fix stage selection does not take into account
    parent creation timestamp
  * refactor: rename StageID.UniqueID to StageID.CreationTs
  * chore(release): 1.2 alpha,beta,ea,stable, 2 alpha,beta
* Wed Jul  3 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.6.5:
  * chore: release 2.6.5
  * fix(build): fix `panic: got bad timestamp ""` when Created not
    present in base image
  * chore(release): 1.2 stable, 2 beta,ea,stable,rock-solid
  * fix(build, stapel): fix fromLatest does not work properly with
    index manifest
  * refactor: remove unused code
  * fix(deploy): werf helm ugprade aborts if last release Pending
  * refactor(deploy): move uninstall-related code from dismiss.go
    to Nelm
  * chore(release): 1.2 beta, ea
  * chore(release): 1.2 alpha, 2 alpha
* Wed Jul  3 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.6.4:
  * chore: release 2.6.4
  * fix(build, cache-repo): fix "panic: runtime error: info must be
    set for image"
  * chore(channels): bump alpha
* Wed Jun 26 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.6.3:
  * chore: release 2.6.3
  * fix(deploy): errors count in progress report not updating
  * fix(deploy): some STS and DS pods not tracked and their errors
    ignored
  * fix(deploy): ignore false recreation errors during StatefulSet
    tracking
  * fix(deploy): helm rollback not adding release metadata to
    created resources
  * fix(deploy): rollback error not showed
  * chore(channels): bump alpha
* Wed Jun 26 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.6.2:
  * test(deploy): fix expect with old error message
  * refactor(deploy): move deploy-related code from render.go to
    Nelm
  * chore: release 2.6.2
  * chore(release): 1.2 rock-solid, 2 beta,ea,stable,rock-solid
  * test(build): temporary disable annoying flaky multiplatform
    build test
  * refactor(deploy): move deploy-related code from plan.go to Nelm
  * docs(build): update docs about using mirrors
  * docs: regenerate cli
  * refactor(deploy): move deploy-related code from converge.go to
    Nelm
  * fix(build): publish custom tags and final images in parallel
  * chore(release): 1.2 alpha
  * chore(release): 1.2 stable, 2 beta,ea,stable
* Tue Jun 18 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.6.1:
  * Add StackOverflow to README
  * chore: release 2.6.1
  * fix: "docker-compose": executable file not found error
  * test(deploy): disable test that stopped working due to skipping
    releases
  * chore(channels): bump alpha
* Fri Jun 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.6.0:
  * chore: release 2.6.0
  * docs: fix urls
  * feat(deploy): release namespace management v2
  * chore(release): 1.2 ea, 2 beta,ea
  * feat(export): add introspect and parallel cli options
  * fix(common): fix panic "unexpected regexp find submatch for
    reference"
  * chore(release): 2 alpha,beta
* Fri Jun  7 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.5.0:
  * chore: release 2.5.0
  * fix(build, buildah, dockerfile): fix multi-stage does not work
    properly
  * feat(build, dockerfile, multiplatform): support automatic
    platform ARGs
  * fix(dev): disable signing for service commits
  * docs(build): fix links
  * chore(channels): bump alpha
* Fri Jun  7 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.4.1:
  * chore(ci): add "." to slack message as a workaround for "empty
    commit message"
  * docs(plan): add docs about werf plan
  * chore: release 2.4.1
  * fix(deploy): bundle apply not overriding project.werf.io/env
    annotation
  * docs(build): move docker.io mirrors doc
  * fix(deploy): panics when some manifest fields are of wrong type
  * chore(channels): bump alpha 1.2, 2
  * docs(contributing): update supported scopes
  * docs(contributing): update supported scopes
  * chore(channels): bump alpha channels 1.2
  * chore(channels): bump alpha channels 1.2, 2
* Sat Jun  1 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.4.0:
  * docs(build): new `--container-registry-mirror` option
  * chore: release 2.4.0
  * feat(build): new option --container-registry-mirror
  * chore(release): 1.1 all
  * chore(channels): bump all channels 1.2, 2
* Thu May 30 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.3.3:
  * chore: release 2.3.3
  * chore(channels): bump alpha 1.2, 2
  * fix(build, buildah): multiple registry mirrors broken
* Thu May 30 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.3.2:
  * chore(channels): bump alpha 1.2, 2
  * chore: release 2.3.2
  * fix(build, buildah): prefix registries mirrors with https /2
  * chore(channels): bump 1.2, 2 alpha
* Thu May 30 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.3.1:
  * chore: release 2.3.1
  * fix(build, buildah): prefix registries mirrors with https
  * fix(build, buildah): add default registry for mirrors docker.io
  * chore(release): 1.2 alpha
  * chore(release): 2 alpha
* Thu May 30 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.3.0:
  * chore: release 2.3.0
  * feat(build, buildah): support mirror registries (v1)
  * feat(other): use docker hub if registry address not specified
    in `werf cr`
  * docs(contributing): update supported scopes
  * chore(ci): fix coverage report
  * docs(contributing): update supported scopes
  * chore(release): bump beta
  * docs(contributing): simplify supported scopes
  * chore(release): 1.2 alpha
  * Update CONTRIBUTING.md
  * Update CONTRIBUTING.md
  * Update CONTRIBUTING.md
  * chore(channels): bump alpha
* Fri May 24 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.2.0:
  * Features
  - build: publish custom tags and final images in parallel
    (ff2843a)
  - deploy: new werf.io/deploy-dependency-<name> annotation
    (3e76f87)
  - harbor: try to get the image again due to
    PROJECTPOLICYVIOLATION error (b7044c1)
  * - Bug Fixes
  - deploy: werf.io/deploy-dependency-.. anno params should be
    comma-separated (17639e5)
  - prevent growing TCP connections by using a shared HTTP
    transport (59f4ec8)
* Tue May 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.1.0:
  * test(v2): fix outdated giterminism tests
  * chore: release 2.1.0
  * fix(deploy): stable resource sorting in Helm release manifests
  * chore: go mod tidy
  * feat(values): env WERF_EXPERIMENT_NO_GLOBAL_SERVICE_VALUES=1
    will disable global service values
  * Fix docs of Usage - Build - Stapel
  * chore: bump channels for 1.1
  * Partially revert "ci(v2): fix v1.2 and v2 releasing"
  * ci(v2): fix v1.2 and v2 releasing
  * docs: fix documentation.yml path in regen.sh
* Tue May 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.0.4:
  * chore: bump channels
  * chore: release 2.0.4
  * fix(docs): fix routing /3
  * docs: fix routing /2
  * fix: docs routing
  * fix(ci-env): fix unable to copy
    "/Users/username/.docker/mutagen"
  * chore(ci): fix notifications (#6101)
  * Sync with EN as part of werf 2.0 release
  * Sync overview.md with EN as part of werf 2.0 release
  * Sync with EN as part of werf 2.0 release
  * Sync with EN - minor fix
  * Sync deployment_order.md with EN as part of werf 2.0 release
  * Sync comparison.md with EN
  * doc(v2): fix breadcrumb
  * doc(v2): update documentation for v2
  * doc(v2): fix migration to v2 guide
  * doc(v2): fix old v1.2 link
  * doc(v2): fix breadcrumb
  * doc(v2): add werf 2.0 migration guide
  * ci(v2): export 1.2 werf images also
  * chore: bump channels
* Thu Apr 25 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.0.3:
  Bug Fixes
  * v2: replace leftovers of v1.2 to v2 /2 (d6cacfb)
* Wed Apr 24 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.0.2:
  * fix(v2): panic with --add-annotations
* Wed Apr 24 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.0.1:
  * Bug Fixes
  - cleanup: remove unnecessary specific implementation for
    selectel (88d0d65)
  - v2: werf version is always dev (9876a4e)
* Wed Apr 24 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.0.0:
  Major update!
  * Features
  - new 2.0 release (16a2ac7)
  - new major v2 release (e15cf3c)
  - v2: "werf render" now uses Nelm (03e05a5)
  - v2: remove --...-implementation flags (82b548f)
  - v2: remove deprecated --report-path and --report-format
    (4f26904)
  - v2: remove deprecated --skip-build option (14d1c72)
  - v2: remove deprecated --tag/--to-tag/--repo from "werf bundle
    copy" (1a4bea1)
  - v2: remove deprecated "werf_image" Helm templates function
    (8721568)
  - v2: switch "werf bundle render" to Nelm (24f3042)
  * Bug Fixes
  - deploy: incorrect error message when release lock fails
    (7f60ccc)
  - remove deprecated werf bundle export/download commands
    (dd9bc09)
  - v2: dont save service annotations in release secret (27d6c4d)
  - v2: enable Nelm by default, remove option to switch back to
    the old engine (9df5245)
  - v2: remove automigration from helm 2 to helm 3 releases
    (316caee)
  - v2: replace leftovers of v1.2 with v2 (940fefe)
* Wed Apr 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.2.307:
  * chore: bump channels
  * chore: release 1.2.307
  * docs: update reference
  * feat(nelm): switch back to the old deployment engine by default
* Wed Apr 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.2.306:
  * chore: release 1.2.306
  * fix(nelm): release namespace and hook never deleted (except
    recreation)
  * fix(nelm): multiple delete policies ignored
  * (tests): Update e2e and integration tests for Kubernetes
    (#6049)
  * chore: 1.2.305 to alpha
* Fri Apr  5 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.2.305:
  * chore: release 1.2.305
  * fix(nelm): --save-deploy-report not saving report on skipped
    release /2
* Fri Apr  5 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.2.304:
  * chore: release 1.2.304
  * fix(nelm): --save-deploy-report not saving report on skipped
    release
  * fix(doc): remove references to werf.yaml and .helm from
    commands that ignore project configs
  * chore(ci): add "." to slack message as a workaround for "empty
    commit message"
  * chore: 1.2.303 to alpha
* Fri Apr  5 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.2.303:
  * chore: release 1.2.303
  * feat(nelm): skip removal of resources with missing/incorrect
    release annotations and labels
  * fix(nelm): "werf converge" panics on first release
  * fix(nelm): allow empty helm.sh/hook-delete-policy and
    werf.io/delete-policy
  * feat(deps): update Nelm
  * fix(nelm): don't skip release if all resources up-to-date but
    the release itself changed
  * doc(nelm): update reference
  * feat(nelm): deploy bundles using new deployment engine
  * chore: bump channels
  * fix(nelm): missing expected annotations values in adoption
    errors
  * chore(tests): disable old integration tests broken by enabling
    Nelm /2
  * chore(tests): disable old integration tests broken by enabling
    Nelm
  * Revert "chore(channels): 1.2 stable"
  * chore(channels): alpha to 1.2.302, beta to 1.2.301
* Wed Apr  3 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.2.302:
  * nelm: change propagation policy on DELETE from Auto to
    Foreground (d7906f0)
* Fri Mar 29 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.2.301:
  * chore: release 1.2.301
  * feat(deps): mini bump all modules
  * fix(stapel): using suitable stage might break reproducibility
    of subsequent stages
  * refactor: small improvement
  * fix(stapel): copying suitable stage from secondary might break
    reproducibility of subsequent stages
  * fix(stapel): discarding newly built image might break
    reproducibility of subsequent stages
  * fix(nelm): don't show logs produced before current release
  * fix(nelm): --status-progress-period=-1 panics
  * fix(buildah): "unknown version specified" error
  * fix(buildah): unable to find "pasta" binary
  * fix(buildah): "could not find netavark" error
  * fix(nelm): tracking might hang with
    werf.io/track-termination-mode: "NonBlocking"
  * chore(channels): 1.2 beta, ea, stable
  * chore: format files
  * fix(deps): update all direct dependencies
  * fix(deps): update Helm to v3.14.3
  * fix: e2e converge tests after Nelm migration
  * fix(nelm): Jobs not failing on errors /2
* Thu Mar 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.2.300:
  * chore: release 1.2.300
  * fix(nelm): Jobs not failing on errors /2
  * feat: make werf root command embeddable
* Thu Mar 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.2.299:
  * chore: release 1.2.299
  * chore(channels): alpha to 1.2.299
  * fix(nelm): Jobs not failing on errors
* Thu Mar 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.2.298:
  * chore(channels): alpha to 1.2.298
  * doc: regenerate reference
  * chore: release 1.2.298
  * docs: add a link to the Argo CD integration article (#6000)
  * fix(nelm): WERF_DIR ignored for chart path
  * chore(channels): rollback alpha to 1.2.295
  * chore(channels): alpha to 1.2.297 (enable Nelm by default)
* Tue Mar 19 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.2.297:
  * chore: release 1.2.297
  * fix(nelm): panic with werf.io/replicas-on-creation
  * chore(channels): 1.2 beta, stable, rock-solid
  * feat(nelm): show release name/namespace on converge/plan start
  * feat(nelm): improve log coloring
  * feat(nelm): remove excessive operations summary
  * feat(nelm): show NOTES.txt on release
  * fix(nelm): removing child chart values with null
* Sun Mar 17 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.2.296:
  * chore: release 1.2.296
  * feat(nelm): activate new deployment engine Nelm by default
  * chore(channels): revert 1.2 rock-solid
  * chore: bump alpha
* Sun Mar 17 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.2.295:
  * chore: release 1.2.295
  * fix(ssh): initialize ssh agent before working with git repo
  * fix(nelm): deployment tracking hangs; old pods tracked
  * chore(channels): ea, rock-solid
  * chore(channels): 1.2 beta, ea, stable
* Tue Feb 20 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.2.294:
  * chore: release 1.2.294
  * chore: bump alpha
  * fix(deploy): dont strip non-whitespace after --- in manifests
  * chore: bump alpha
* Tue Feb 20 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.2.293:
  * chore: release 1.2.293
  * fix: more robust manifest splitting
  * fix(nelm): corrupted revision number in errors messages
  * docs: regenerate reference
* Sun Feb 18 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.2.292:
  * chore: bump alpha
  * chore: release 1.2.292
  * feat: add --atomic, --timeout, --skip-dependencies-repo-refresh
    for "bundle apply"
  * docs: fix adding arbitrary files to the build context example
  * chore: bump alpha
* Sun Feb 18 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.2.291:
  * chore: release 1.2.291
  * fix(bundle): support for
  - -insecure-registry/--skip-tls-verify-registry options
  * fix(nelm): cycle error if pre+post hook in release
  * fix(cleanup): git unshallow and sync with remote when git
    history based policy disabled
  * fix(build): image metadata publication when git history based
    policy disabled
  * fix(cleanup): image metadata cleanup when git history based
    policy disabled
  * chore: bump alpha
* Wed Feb 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.2.290:
  * chore: bump stable
  * chore: release 1.2.290
  * chore(channels): rollback stable to 1.2.277 due to error
    'Error: validation: more than one dependency with name or alias
    ...
  * feat(nelm): save plan graph on plan build error
  * fix(nelm): panic on replicas null
  * chore(channels): 1.2 beta, stable, rock-solid
  * chore: bump alpha
* Thu Feb  8 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.2.289:
  * chore: release 1.2.289
  * fix: --wait-for-jobs did not use Kubedog
  * chore: bump alpha, beta, ea
* Thu Feb  8 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.2.288:
  * chore: release 1.2.288
  * fix(nelm): controllers not Readying; no logs for STS/DS
  * chore(channels): 1.2 beta, ea
  * chore: bump alpha
* Fri Feb  2 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.2.287:
  * chore: release 1.2.287
  * fix(nelm): resources always rendered in no-cluster mode
  * fix(cleanup): issue with incorrect exclusion of ancestors for
    retained images (#5956)
  * chore: bump alpha, beta
* Thu Feb  1 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.2.286:
  * chore: release 1.2.286
  * fix: dont try to create namespace if exists
  * chore: bump alpha
* Thu Feb  1 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.2.285:
  * chore: release 1.2.285
  * fix(nelm): pods not ready in progress report when they are
  * ci: trigger website deploy when a new release is created
    (#5951)
  * chore(channels): 1.2 beta, ea, stable, rock-solid
  * chore: bump alpha
* Wed Jan 31 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.2.284:
  * chore: release 1.2.284
  * feat(nelm): --auto-rollback support for converge
  * fix(nelm): refactor pending release check in converge
  * fix(nelm): refactor failure deploy plan in converge
  * fix(nelm): refactor error handling in converge
* Wed Jan 31 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.2.283:
  * chore: release 1.2.283
  * feat(compose): use host docker binary instead of docker-compose
    (#5944)
  * chore: bump alpha
  * feat(nelm): heavily improved resource tracking
  * chore(channels): 1.2 alpha, beta (#5940)
* Wed Jan 31 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.2.282:
  * chore: release 1.2.282 (#5938)
  * fix(cleanup): panic: runtime error: invalid memory address or
    nil pointer dereference (#5937)
  * chore(channels): alpha to 1.2.281
* Sat Jan 20 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.2.281:
  * chore: release 1.2.281
  * feat(nelm): --exit-code flag for werf plan
  * fix: update helm, nelm modules
  * chore(channels): alpha rollback to 1.2.278
  * chore(channels): alpha to 1.2.280
  * chore(channels): downgrade 1.2 alpha
  * Revert "chore(deps): bump nokogiri from 1.15.5 to 1.16.0 in
    /docs" (#5933)
  * chore(channels): alpha to 1.2.280
* Wed Jan 17 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.2.280:
  * doc: fix doc tests
  * chore: release 1.2.280
  * fix: switch to go 1.21
  * chore(channels): alpha to 1.2.279
  * chore(channels): 1.2 beta, ea, stable, rock-solid (#5929)
  * fix: disable dependabot
* Wed Jan 17 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.2.279:
  * chore: release 1.2.279
  * fix: update more modules, get rid of minio
  * doc: regenerate docs
  * fix: update all go modules
  * chore(deps): bump nokogiri from 1.15.5 to 1.16.0 in /docs
  * chore: replace satori/go.uuid with google/uuid (#5905)
  * ci: fix workflow for documentation (#5917)
  * chore(channels): bump channels
  * chore(channels): 1.2.278 to alpha
* Wed Jan 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.2.278:
  * doc: update env function docs
  * ci: fix workflow, fix build, update dependencies for the
    documentation (#5914)
  * chore: release 1.2.278
  * chore(ci): rollback download-artifact action from master to v3
  * ci: fix workflow, fix build, update dependencies for the
    documentation (#5914)
  * chore(ci): rollback upload-artifact action from master to v3
  * chore: fix lint
  * fix(deps): update helm-plugin-utils
  * ci: fix workflow for documentation (#5910)
  * fix(deps): update go-git
  * ci: fix workflow for documentation (#5907)
  * ci: use enterprise runners (#5874)
  * chore(deps): bump jekyll from 4.3.2 to 4.3.3 in /docs
  * chore(deps): bump nokogiri from 1.15.5 to 1.16.0 in /docs
  * chore(channels): 1.2.277 to alpha
* Sun Jan  7 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.2.277:
  * chore: release 1.2.277
  * fix: Nelm moved to separate repo
  * fix: add WERF_NELM var (same as
    WERF_EXPERIMENTAL_DEPLOY_ENGINE)
  * chore(channels): 1.2 all channels (#5899)
* Sun Jan  7 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.2.276:
  * chore: release 1.2.276 (#5898)
  * fix: pre-collapsed gitlab section not usable (#5897)
  * chore(channels): 1.2.275 -> alpha, 1.2.274 -> beta
* Sun Jan  7 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.2.275:
  * chore: release 1.2.275
  * fix(build): files from git with spaces in path not removed on
    install/beforeSetup/setup patch-stages
  * chore(channels): 1.2.274 into alpha
* Thu Dec 21 2023 opensuse_buildservice@ojkastl.de
- Update to version 1.2.274:
  * chore: release 1.2.274
  * fix(buildah): fix digest change on rebuild of
    install/beforeSetup/setup stage when using multiple
    git-mappings in the same image
  * chore(channels): 1.2.273 to alpha
* Thu Dec 21 2023 opensuse_buildservice@ojkastl.de
- Update to version 1.2.273:
  * chore: release 1.2.273
  * fix(exp-engine): "no matches for kind" when deploying CR for
    CRD from crds/
* Wed Dec 20 2023 opensuse_buildservice@ojkastl.de
- Update to version 1.2.272:
  * chore(channels): 1.2.272 to alpha
  * chore: release 1.2.272
  * feat: improve generic resource tracking
  * chore(channel): 1.2 stable (#5886)
  * fix(staged-dockerfile): explanatory error message when building
    unsupported Dockerfile conf
  * chore(channels): 1.2.171 hotfix into alpha, beta and ea
* Thu Dec 14 2023 kastl@b1-systems.de
- Update to version 1.2.271:
  * chore: release 1.2.271
  * fix(secrets): empty secrets values yaml file results in werf
    error
  * docs(configurator-separate-pages): serve
    /documentation/X/configurator/*.html pages
  * chore(channels): rollback to 1.2.269
  * chore(channels): 1.2 ea, stable, rock-solid (#5877)
  * chore(channels): 1.2 beta, ea (#5873)
  * chore(channels): 1.2 alpha (#5872)
* Sun Dec 10 2023 kastl@b1-systems.de
- Update to version 1.2.270:
  * chore: release 1.2.270 (#5868)
  * fix(secrets): fix double decryption error when decrypting a
    yaml with multiple references to the same anchor
  * feat(container): implement generic Retry-After header handling
    (#5867)
  * chore: fix lint failed (#5865)
  * chore(channels): 1.2 beta, ea, stable (#5864)
  * docs(bundles): move cr login section after overview (#5861)
  * chore(deps): bump nokogiri from 1.15.4 to 1.15.5 in /docs
  * chore: release 1.2.269 (#5847)
  * chore(channels): 1.2 alpha (#5848)
* Sun Dec 10 2023 Johannes Kastl <kastl@b1-systems.de>
- new package werf: efficient and consistent software delivery to
  Kubernetes facilitating best practices
